==> cordova-sqlite-react-1.1.37.tgz: package/src/SqliteFunction/updateDataSqlite.ts <==
import { updateDataSqliteT } from './../common';
import { generateSQLUpdate } from './../stringSQL/generateUpdate';





export const updateDataSqlite:updateDataSqliteT = (connect, nameTable, payload, {where, condition, stringWhere}) => {
  return new Promise((resolve, reject) => {

    let { newSQLUpdate, arrValuesPayload } = generateSQLUpdate(nameTable, payload, {where, condition, stringWhere});
    
    connect.transaction(
      (tx) => {
        tx.executeSql( newSQLUpdate, arrValuesPayload);
      },
      (err) => { 
        let msg = `>>> Ошибка в -> updateDataSqlite <<<: ${nameTable}:  ${err}`
        reject({status: false, msg})
      },
      () => { 
        let msg = `Успешная транзакция updateDataSqlite. ${nameTable}`;
        resolve({status: true, msg}) 
      }
    )
  })
}



// export function overwriteOldData (nameTable, keyName, version, rawData) {
//   return new Promise((resolve, reject) => {
//     console.group('overwriteOldData')
//     console.log('---------------------------------------------');
//     console.log('keyName', keyName);
//     console.log('version', version);
//     console.log('rawData', rawData);
//     console.log('---------------------------------------------');
//     if(window.cordova && window.sqlitePlugin){ 
//       let db = openDbSqlite();
        
//       db.transaction(
//         (tx) => {
          
//           console.dir(`UPDATE ${nameTable} SET version = ?, rawData = ? WHERE name="${keyName}"`);
//           tx.executeSql(`UPDATE ${nameTable} SET version = ?, rawData = ? WHERE name="${keyName}"`, 
//             [
//               (typeof version  === 'string') ? Number(version) : version,
//               ((typeof rawData === 'object') || (typeof rawData === 'boolean')) ? JSON.stringify(rawData) : rawData.trim(),
//             ],
//             (tx, res) => {
//               console.dir('Данные обновлены возвращаю res.insertId');
//               console.dir(res);

//               resolve(res.insertId); 
//             },
//             (tx, err) => console.error(err)
//           ); 
//         },
//         //При проверке таблицы не закрывать бд т.к. она закрывается в момент транзакции getDataFromSqlite
//         (error) => { console.log('Ошибка транзакции в overwriteOldData: '); reject(error);  }, 
//         () => { console.log('Успех транзакции overwriteOldData');  } 
//       );

//       return;
//     }
//     reject(new Error('Не установлен плагин cordova || cordova-sqlite-storage'));

//   })
// }

==> cordova-sqlite-react-1.1.41.tgz: package/src/SqliteFunction/updateDataSqlite.ts <==
import { updateDataSqliteT } from './../common';
import { generateSQLUpdate } from './../stringSQL/generateUpdate';





export const updateDataSqlite:updateDataSqliteT = (connect, nameTable, payload, {where, condition, stringWhere}) => {
  return new Promise((resolve, reject) => {

    let { newSQLUpdate, arrValuesPayload } = generateSQLUpdate(nameTable, payload, {where, condition, stringWhere});
    
    connect.transaction(
      (tx) => {
        tx.executeSql( newSQLUpdate, arrValuesPayload);
      },
      (err) => { 
        let msg = `>>> Ошибка в -> updateDataSqlite <<<: ${nameTable}:  ${err}`
        reject({status: false, msg})
      },
      () => { 
        let msg = `Успешная транзакция updateDataSqlite. ${nameTable}`;
        resolve({status: true, msg}) 
      }
    )
  })
}



// export function overwriteOldData (nameTable, keyName, version, rawData) {
//   return new Promise((resolve, reject) => {
//     console.group('overwriteOldData')
//     console.log('---------------------------------------------');
//     console.log('keyName', keyName);
//     console.log('version', version);
//     console.log('rawData', rawData);
//     console.log('---------------------------------------------');
//     if(window.cordova && window.sqlitePlugin){ 
//       let db = openDbSqlite();
        
//       db.transaction(
//         (tx) => {
          
//           console.log(`UPDATE ${nameTable} SET version = ?, rawData = ? WHERE name="${keyName}"`);
//           tx.executeSql(`UPDATE ${nameTable} SET version = ?, rawData = ? WHERE name="${keyName}"`, 
//             [
//               (typeof version  === 'string') ? Number(version) : version,
//               ((typeof rawData === 'object') || (typeof rawData === 'boolean')) ? JSON.stringify(rawData) : rawData.trim(),
//             ],
//             (tx, res) => {
//               console.log('Данные обновлены возвращаю res.insertId');
//               console.log(res);

//               resolve(res.insertId); 
//             },
//             (tx, err) => console.error(err)
//           ); 
//         },
//         //При проверке таблицы не закрывать бд т.к. она закрывается в момент транзакции getDataFromSqlite
//         (error) => { console.log('Ошибка транзакции в overwriteOldData: '); reject(error);  }, 
//         () => { console.log('Успех транзакции overwriteOldData');  } 
//       );

//       return;
//     }
//     reject(new Error('Не установлен плагин cordova || cordova-sqlite-storage'));

//   })
// }
